@@ -166,14 +166,14 @@ class VPS(_defaults_.Defaults):
 
 		# deploy.
 		if log_level >= 0: loader.mark(new_message=f"Deploying domain {self.domain} on vps {self.ip}")
-		response = ssht00ls.ssh.command(
+		output = ssht00ls.ssh.command(
 			alias=self.domain,
 			command=f"python3 {installed_location}/website.py --deploy{installer_arguments} --non-interactive",
 			log_level=-1,)
-		if not response.success or not "Successfully deployed domain https://" in response.output:
+		if not output.success or "Successfully deployed domain https://" not in output:
 			#print(response)
 			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error: {response.error}.", log_level=log_level)
+			return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error: {output}.", log_level=log_level)
 
 		# handler.
 		if log_level >= 0: loader.stop()
